pub struct BlockDevice { /* private fields */ }Expand description
A sector-addressed block device.
Implementations
Sourceimpl BlockDevice
impl BlockDevice
Sourcepub fn from_file(path: impl AsRef<Path>) -> Result<BlockDevice>
pub fn from_file(path: impl AsRef<Path>) -> Result<BlockDevice>
A device backed by the contents of a host file.
Sourcepub fn sector_count(&self) -> i64
pub fn sector_count(&self) -> i64
How many whole or partial sectors the image contains.